@@ -33,18 +33,19 @@ mkParams(vector<Node const*> const &parents, unsigned int nchain)
 LogicalNode::LogicalNode(vector<unsigned int> const &dim, 
 			 vector<Node const *> const &parameters,
 			 Function const *function)
-    : DeterministicNode(dim, parameters), _func(function), 
+    : DeterministicNode(dim, parameters), _func(function), _discrete(false), 
       _parameters(mkParams(parameters, nchain()))
 {
-    /*
-    for (unsigned int n = 0; n < nchain(); ++n) {
-	_parameters[n].reserve(parameters.size());
-	for (unsigned long j = 0; j < parameters.size(); ++j) {
-	    _parameters[n].push_back(parameters[j]->value(n));
-	}
-	
+    if (!function->checkNPar(parameters.size())) {
+	string msg = "Incorrect number of parameters for function " +
+	    function->name();
+	throw runtime_error(msg);
     }
-    */
+    vector<bool> mask(parents().size());
+    for (unsigned long j = 0; j < parents().size(); ++j) {
+        mask[j] = parents()[j]->isDiscreteValued();
+    }
+    _discrete = _func->isDiscreteValued(mask);
 }
 
 string LogicalNode::deparse(vector<string> const &parents) const
@@ -98,9 +99,5 @@ bool LogicalNode::isClosed(set<Node const *> const &ancestors,
 
 bool LogicalNode::isDiscreteValued() const
 {
-    vector<bool> mask(parents().size());
-    for (unsigned long j = 0; j < parents().size(); ++j) {
-        mask[j] = parents()[j]->isDiscreteValued();
-    }
-    return _func->isDiscreteValued(mask);
+    return _discrete;
 }
