@@ -27,7 +27,7 @@ ParallelSampler::~ParallelSampler()
     }
 }
 
-void ParallelSampler::update(std::vector<RNG*> const &rngs)
+void ParallelSampler::update(vector<RNG*> const &rngs)
 {
     for (unsigned int ch = 0; ch < rngs.size(); ++ch) {
 	_methods[ch]->update(rngs[ch]);
