@@ -11,15 +11,14 @@ using std::string;
 
 namespace base {
 
-    TraceMonitor::TraceMonitor(Node const *node, unsigned int start, 
-			       unsigned int thin)
-	: Monitor("trace", node, start, thin), _values(node->nchain())
+    TraceMonitor::TraceMonitor(Node const *node)
+	: Monitor("trace", node), _values(node->nchain())
     {
     }
-
-    void TraceMonitor::doUpdate()
+    
+    void TraceMonitor::update()
     {
-	Node const *snode = node();
+	Node const *snode = nodes()[0];
 	unsigned int nchain = snode->nchain();
 	unsigned int length = snode->length();
 	for (unsigned int ch = 0; ch < nchain; ++ch) {
@@ -37,46 +36,24 @@ namespace base {
 
     vector<unsigned int> TraceMonitor::dim() const
     {
-	vector<unsigned int> dim = node()->dim();
-	dim.push_back(niter());
-	dim.push_back(nchain());
-	return dim;
-    }
-
-    unsigned int TraceMonitor::nchain() const
-    {
-	return node()->nchain();
+	return nodes()[0]->dim();
     }
 
     void TraceMonitor::reserve(unsigned int niter)
     {
-	unsigned int N = (1 + niter / thin()) * node()->length();
+	unsigned int N = niter * nodes()[0]->length();
 	for (unsigned int ch = 0; ch < _values.size(); ++ch) {
 	    _values[ch].reserve(_values[ch].size() + N);
 	}
     }
 
-    SArray TraceMonitor::dump() const
+    bool TraceMonitor::poolChains() const
     {
-	vector<unsigned int> d = dim();
-	SArray ans(d);
-	unsigned int length = _values[0].size(); 
-	unsigned int nch = _values.size();
+	return false;
+    }
 
-	vector<double> v(length * nch);
-	for (unsigned int ch = 0; ch < nch; ++ch) {
-	    for (unsigned int i = 0; i < length; ++i) {
-		v[i + ch * length] = _values[ch][i];
-	    }
-	}
-	ans.setValue(v);    
-	
-	int ndim = d.size();
-	vector<string> names(ndim);
-	names[ndim-2] = "iteration";
-	names[ndim-1] = "chain";
-	ans.setDimNames(names);
-	
-	return(ans);
+    bool TraceMonitor::poolIterations() const
+    {
+	return false;
     }
 }
