@@ -15,7 +15,8 @@ class RealDSum : public RWDSum
 {
 public:
     RealDSum(GraphView const *gv, unsigned int chain);
-    void step(std::vector<double> &value, double s, RNG *rng) const;
+    void step(std::vector<double> &value, unsigned int nrow, 
+	      unsigned int ncol, double s, RNG *rng) const;
     std::string name() const;
 };
 
