@@ -13,7 +13,7 @@ namespace glm {
 	HolmesHeld(GraphView const *view, 
 		   std::vector<GraphView const *> const &sub_views,
 		   unsigned int chain);
-	void updateAuxiliary(double *b, csn *N, RNG *rng);
+	void updateAuxiliary(cholmod_dense *b, cholmod_factor *N, RNG *rng);
 	std::string name() const;
 	void update(RNG *rng);
     };
